@@ -2,7 +2,6 @@ from os import path
 from pylode.common import VERSION, TEMPLATES_DIR, STYLE_DIR
 import collections
 from os import path
-import dateutil.parser
 from itertools import chain
 import markdown
 from jinja2 import Environment, FileSystemLoader
@@ -13,8 +12,8 @@ from pylode.profiles.base import BaseProfile
 
 
 class OntDoc(BaseProfile):
-    def __init__(self, g, source_info, outputformat="html", exclude_css=False, default_language="en", get_curies_online=False):
-        super().__init__(g, source_info, outputformat=outputformat, exclude_css=exclude_css, get_curies_online=False, default_language=default_language)
+    def __init__(self, g, source_info, outputformat="html", include_css=False, default_language="en", get_curies_online=False):
+        super().__init__(g, source_info, outputformat=outputformat, include_css=include_css, get_curies_online=False, default_language=default_language)
         self.G.bind("prov", PROV)
         self.CLASSES = collections.OrderedDict()
         self.PROPERTIES = collections.OrderedDict()
@@ -363,9 +362,7 @@ class OntDoc(BaseProfile):
                 # dates
                 if p in [DCTERMS.created, DCTERMS.modified, DCTERMS.issued]:
                     date_type = p.split("/")[-1]
-                    self.METADATA[date_type] = dateutil.parser.parse(str(o)).strftime(
-                        "%Y-%m-%d"
-                    )
+                    self.METADATA[date_type] = str(o)
 
                 if p == DCTERMS.source:
                     if str(o).startswith('http'):
@@ -464,7 +461,7 @@ class OntDoc(BaseProfile):
                     self.CLASSES[cls]["description"] = markdown.markdown(str(o))
 
                 if p == SKOS.scopeNote:
-                    self.CLASSES[cls]["scopeNote"] = str(o)
+                    self.CLASSES[cls]["scopeNote"] = markdown.markdown(str(o))
 
                 if p == SKOS.example:
                     self.CLASSES[cls]["example"] = str(o)
@@ -652,7 +649,7 @@ class OntDoc(BaseProfile):
                 if p == RDFS.label:
                     self.PROPERTIES[prop]["title"] = str(o)
 
-                if p == RDFS.comment:
+                if p == DCTERMS.description:
                     self.PROPERTIES[prop]["description"] = str(o)
 
                 if p == SKOS.scopeNote:
@@ -1090,7 +1087,7 @@ class OntDoc(BaseProfile):
     def _make_document(self):
         css = None
         if self.outputformat == "html":
-            if not self.exclude_css:
+            if self.include_css:
                 css = open(path.join(STYLE_DIR, "pylode.css")).read()
 
         return self._load_template("document." + self.outputformat).render(
