@@ -3,7 +3,6 @@ import collections
 from os import path
 from rdflib import URIRef, BNode, Literal
 from rdflib.namespace import DC, DCTERMS, DOAP, OWL, PROV, RDF, RDFS, SDO, SKOS
-import dateutil.parser
 from itertools import chain
 import markdown
 from jinja2 import Environment, FileSystemLoader
@@ -12,8 +11,8 @@ from pylode.profiles.base import BaseProfile
 
 
 class VocPub(BaseProfile):
-    def __init__(self, g, source_info, outputformat="html", exclude_css=False, default_language="en", get_curies_online=False):
-        super().__init__(g, source_info, outputformat=outputformat, exclude_css=exclude_css, get_curies_online=False, default_language=default_language)
+    def __init__(self, g, source_info, outputformat="html", include_css=False, default_language="en", get_curies_online=False):
+        super().__init__(g, source_info, outputformat=outputformat, include_css=include_css, get_curies_online=False, default_language=default_language)
         self.CONCEPTS = collections.OrderedDict()
         self.COLLECTIONS = collections.OrderedDict()
 
@@ -359,9 +358,7 @@ class VocPub(BaseProfile):
                 # dates
                 if p in [DCTERMS.created, DCTERMS.modified, DCTERMS.issued]:
                     date_type = p.split("/")[-1]
-                    self.METADATA[date_type] = dateutil.parser.parse(str(o)).strftime(
-                        "%Y-%m-%d"
-                    )
+                    self.METADATA[date_type] = str(o)
 
                 if p == DCTERMS.source:
                     if str(o).startswith('http'):
@@ -573,7 +570,7 @@ class VocPub(BaseProfile):
     def _make_document(self):
         css = None
         if self.outputformat == "html":
-            if not self.exclude_css:
+            if self.include_css:
                 css = open(path.join(STYLE_DIR, "pylode.css")).read()
 
         return self._load_template("taxonomy." + self.outputformat).render(
